cli

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 9, 2026 License: MIT Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(ctx context.Context) int

Execute runs the root command with a context canceled by SIGINT/SIGTERM.

func NewRootCommand

func NewRootCommand() *cobra.Command

NewRootCommand builds the root cobra command. Tests may call this directly to avoid invoking os.Exit via Execute.

Types

This section is empty.

Jump to